function agent = EstimatorPrediction(agent,estModel)
% Perform estimator prediction locally on agent.
% 
% Inputs:
%   agent       agent's state struct
%   estModel    system model as used for estimation
%
% Output:
%   agent       agent's state struct (updated)
%
% --
% Supplementary material (simulation examples) to:
%   Distributed Event-based State Estimation (technical report)
%   Event-based State Estimation: An Emulation-based Approach (journal)
%
% Copyright 2015-17 Max Planck Society. All rights reserved.
% 
% Sebastian Trimpe
% Max Planck Institute for Intelligent Systems
% Autonomous Motion Department
% strimpe(at)tuebingen.mpg.de
%
% Revision history
% [07.04.15]   first version


%% Estimation: Prediction
if estModel.flagReducedModel
    % reduced model
    agent.xpred =   estModel.A * agent.xhat + ...
                    estModel.B * agent.uhat + ...
                    estModel.Bminus * agent.uhat_minus;
    agent.uhat_minus = agent.uhat;  % keep for next step
else
    agent.xpred =   estModel.A * agent.xhat + ...
                    estModel.B * agent.uhat;
    % agent.uhat_minus not needed; don't update
end;
